@@ -2,13 +2,11 @@
     管理插件配置，提供读写支持
 '''
 import json
-from pathlib import Path
-from pydantic import BaseModel, ValidationError
-from loguru import logger
-
+from pydantic import ValidationError
 from .helpers import ensure_dir_exists
+from .lazy import logger, BaseModel, Path
 
-AYAKA_VERSION = "1.0.0"
+AYAKA_VERSION = "1.0.1"
 
 data_path = Path("data", "ayaka")
 ensure_dir_exists(data_path)
@@ -43,12 +41,12 @@ class AyakaConfig(BaseModel):
 
         except ValidationError as e:
             logger.error(
-                f"导入配置失败，请检查{name}的配置是否正确")
+                f"导入配置失败，请检查{name}的配置是否正确；如果不确定出错的原因，可以尝试更新插件-删除配置-重启bot")
             raise e
 
         # 强制更新（更新默认值）
         self.save()
-        logger.opt(colors=True).debug(f"已自动载入配置文件 <c>{name}</c>")
+        logger.opt(colors=True).debug(f"已载入配置文件 <g>{name}</g>")
 
     def __setattr__(self, name, value):
         if getattr(self, name) != value:
@@ -72,23 +70,25 @@ class RootConfig(AyakaConfig):
 
 
 ayaka_root_config = RootConfig()
+'''ayaka根配置，目前是吉祥物，仅标识ayaka的版本号'''
+
 ayaka_root_config.version = AYAKA_VERSION
-logger.opt(colors=True).success(f"ayaka当前版本 <y>{AYAKA_VERSION}</y>")
+logger.opt(colors=True).success(f"<y>ayaka</y> 当前版本 <y>{AYAKA_VERSION}</y>")
 
 
 def load_data_from_file(path: Path):
     '''从指定文件加载数据
 
     参数:
-    
+
         path: 文件路径。文件类型，必须是.json文件或.txt文件
 
     返回:
-    
+
         json反序列化后的结果(对应.json文件) 或 字符串数组(对应.txt文件)
 
     异常:
-    
+
         错误的文件类型
     '''
     if path.suffix not in [".json", ".txt"]:
